@@ -1,3 +1,4 @@
+import copy
 import inspect
 import os
 import re
@@ -200,6 +201,22 @@ class Smart(Generic[T]):
     def __repr__(self) -> str:
         return str(self)
 
+    def __copy__(self) -> 'Smart[T]':
+        smart: Smart = Smart(self._callable)
+        smart._params = self._params.copy()
+        smart._trace = self._trace
+        return smart
+
+    def __eq__(
+        self,
+        other: Any,
+    ) -> bool:
+        return (
+            isinstance(other, Smart)
+            and self._callable == other._callable
+            and self._params == other._params
+        )
+
     def keys(
         self,
         flatten: bool = False,
@@ -372,10 +389,58 @@ class Smart(Generic[T]):
         dictionary[last_key] = value = function(dictionary[last_key])
         return value
 
+    def remove(
+        self,
+        *keys: str,
+        required: bool = True,
+    ) -> 'Smart[T]':
+        """Removes given keys from dictionary.
+
+        Args:
+            keys: The keys to remove.
+            required: Whether the all keys are required to exist.
+
+        Returns:
+            Smart object with removed values.
+
+        Raises:
+            ValueError if key is required and doesn't exist.
+
+        """
+        smart: Smart = Smart()
+        for key in keys:
+            if (value := self.pop(key, default=... if required else smart)) is not smart:
+                smart.set(key, value)
+
+        return smart
+
+    def keep(
+        self,
+        *keys: str,
+        required: bool = True,
+    ) -> 'Smart[T]':
+        """Retains given keys and removes the rest from dictionary.
+
+        Args:
+            keys: The key to retain.
+            required: Whether the all keys are required to exist.
+
+        Returns:
+            Removed value.
+
+        Raises:
+            ValueError if key is required and doesn't exist.
+
+        """
+        smart: Smart = self.copy()
+        keep = smart.remove(*keys, required=required)
+        self._params = keep._params
+        return smart
+
     def update(
         self,
         **kwargs: Any,
-    ) -> 'Smart':
+    ) -> 'Smart[T]':
         """Updates existing items with given keyword arguments.
 
         Args:
@@ -394,7 +459,7 @@ class Smart(Generic[T]):
         target_key: Optional[str] = None,
         override: bool = True,
         required: bool = True,
-    ) -> 'Smart':
+    ) -> 'Smart[T]':
         """Updates existing items from given source.
 
         Args:
@@ -463,6 +528,21 @@ class Smart(Generic[T]):
         """
         return cls().update_from(source=source, source_key=key)
 
+    def copy(
+        self,
+        deep: bool = False,
+    ) -> 'Smart[T]':
+        """Creates copy of Smart object.
+
+        Args:
+            deep: Whether to create deep copy.
+
+        Returns:
+            Copy of Smart object.
+
+        """
+        return copy.deepcopy(self) if deep else copy.copy(self)
+
     def init(
         self,
         key: Optional[str] = None,
@@ -531,7 +611,7 @@ class Smart(Generic[T]):
         self,
         function: Optional[Callable[['Smart'], Any]] = None,
         path: Optional[Path] = None,
-    ) -> 'Smart':
+    ) -> 'Smart[T]':
         """Runs main function.
 
         Args:
