@@ -1,9 +1,9 @@
 import os
 import unittest
 
-from smartparams.utils import str_to_bool
+import smartparams.utils.string as strutil
 
-_UNIT = str_to_bool(os.getenv('TEST_UNIT', default='1'))
+_UNIT = strutil.to_bool(os.getenv('TEST_UNIT', default='1'))
 
 
 @unittest.skipUnless(_UNIT, reason="Unit tests are disabled")
