@@ -154,6 +154,27 @@ class TestSmartDictCase(UnitCase):
         self.assertEqual('argument31', self.smart.dict['arg3']['arg31'])
         self.assertEqual('a32', self.smart.dict['arg3']['arg32'])
 
+    def test_remove(self) -> None:
+        actual = self.smart.remove('arg2', 'arg3.arg31')
+
+        self.assertEqual(Smart(arg2=['arg2'], arg3={'arg31': 'a31'}), actual)
+        self.assertEqual(Smart(arg1='arg1', arg3={'arg32': 'a32'}), self.smart)
+
+    def test_keep(self) -> None:
+        actual = self.smart.keep('arg2', 'arg3.arg31')
+
+        self.assertEqual(Smart(arg1='arg1', arg3={'arg32': 'a32'}), actual)
+        self.assertEqual(Smart(arg2=['arg2'], arg3={'arg31': 'a31'}), self.smart)
+
+    def test_keep__required(self) -> None:
+        self.assertRaises(KeyError, self.smart.keep, 'arg2', 'arg3.arg31', 'unknown', required=True)
+
+    def test_keep__no_required(self) -> None:
+        actual = self.smart.keep('arg2', 'arg3.arg31', 'unknown', required=False)
+
+        self.assertEqual(Smart(arg1='arg1', arg3={'arg32': 'a32'}), actual)
+        self.assertEqual(Smart(arg2=['arg2'], arg3={'arg31': 'a31'}), self.smart)
+
     @patch('smartparams.smart.load_data')
     def test_update(self, load_data: Mock) -> None:
         dictionary = {'arg1': {'nested1': 'argument1'}, 'arg3': {'arg31': 'argument31'}}
@@ -247,6 +268,24 @@ class TestSmartDictCase(UnitCase):
 
         self.assertRaises(TypeError, self.smart.update_from, source)
 
+    def test_copy(self) -> None:
+        smart = self.smart.copy()
+
+        self.assertFalse(smart is self.smart)
+        self.assertFalse(smart._params is self.smart._params)
+        self.assertTrue(smart._params['arg2'] is self.smart._params['arg2'])
+        self.assertEqual(smart._trace, self.smart._trace)
+        self.assertTrue(smart._callable is self.smart._callable)
+
+    def test_copy__deep(self) -> None:
+        smart = self.smart.copy(deep=True)
+
+        self.assertFalse(smart is self.smart)
+        self.assertFalse(smart._params is self.smart._params)
+        self.assertFalse(smart._params['arg2'] is self.smart._params['arg2'])
+        self.assertEqual(smart._trace, self.smart._trace)
+        self.assertTrue(smart._callable is self.smart._callable)
+
 
 class TestSmartInitCase(UnitCase):
     def setUp(self) -> None:
